==> pnp4nagios_0.6.12.orig.tar.gz: pnp4nagios-0.6.12/share/pnp/application/i18n/fr_FR/common.php <==
<?php defined('SYSPATH') OR die('No direct access allowed.');
$lang = array
(
    'datasource' => 'Source de données : %s',
    'host' => 'Machine : %s',
    'service' => 'Service : %s',
    'page' => 'Page : %s',
    'page-basket' => 'Page : Panier',
    'zoom-header' => 'Zoom',
    'status-box-header' => 'État',
    'multisite-box-header' => 'Liens multisite',
    'search-box-header' => 'Recherche',
    'icon-box-header' => 'Actions',
    'basket-box-header' => 'Mon panier',
    'timerange-box-header' => 'Plage de temps',
    'service-box-header' => 'Services',
    'special-templates-box-header' => 'Patrons spécifiques',
    'pages-box-header' => 'Pages',
    'nagios-summary-link-title' => 'Alarmes les plus récentes dans cette plage de temps',
    'nagios-avail-link-title'   => 'Disponibilité de Nagios pendant cette plage de temps',
    'timerange-selector-legend' => 'Selectionner une plage de temps',
    'timerange-selector-title'  => 'Selectionner une plage de temps',
    'timerange-selector-submit-button' => 'démarrer',
    'timerange-selector-clear-button'  => 'effacer',
    'timerange-selector-link'          => 'Plage de temps personnalisée',
	'start' => 'Début',
	'end' => 'Fin',
    'service-details' => 'Détails du service',
    'service-overview' => 'Aperçu du service sur "%s"',
	'title-pages-link' => 'Voir la page',
	'title-pdf-link' => 'Extraction PDF',
	'title-xml-link' => 'Extraction XML',
	'title-statistics-link' => 'Voir statistiques internes sur PNP',
	'title-calendar-link' => 'Définir une plage de temps',
    'title-special-templates-link' => 'Voir les patrons',
    'title-docs-link' => 'Accèder à la documentation',
    'title-home-link' => 'Accèder aux graphiques',
    'docs-home' => 'Accueil',
    'docs-box-header' => 'Menu',
    'docs-header' => 'Version de la documentation %s',
);

==> pnp4nagios_0.6.16.orig.tar.gz: pnp4nagios-0.6.16/share/pnp/application/i18n/fr_FR/common.php <==
<?php defined('SYSPATH') OR die('No direct access allowed.');
$lang = array
(
    'datasource' => 'Source de données : %s',
    'host' => 'Machine : %s',
    'service' => 'Service : %s',
    'page' => 'Page : %s',
    'page-basket' => 'Page : Panier',
    'zoom-header' => 'Zoom',
    'status-box-header' => 'État',
    'multisite-box-header' => 'Liens multisite',
    'search-box-header' => 'Recherche',
    'icon-box-header' => 'Actions',
    'basket-box-header' => 'Mon panier',
    'timerange-box-header' => 'Plage de temps',
    'service-box-header' => 'Services',
    'special-templates-box-header' => 'Patrons spécifiques',
    'pages-box-header' => 'Pages',
    'nagios-summary-link-title' => 'Alarmes les plus récentes dans cette plage de temps',
    'nagios-avail-link-title'   => 'Disponibilité de Nagios pendant cette plage de temps',
    'timerange-selector-legend' => 'Selectionner une plage de temps',
    'timerange-selector-title'  => 'Selectionner une plage de temps',
    'timerange-selector-submit-button' => 'démarrer',
    'timerange-selector-clear-button'  => 'effacer',
    'timerange-selector-link'          => 'Plage de temps personnalisée',
    'timerange-selector-overview'      => 'Overview',
    'start' => 'Début',
    'end' => 'Fin',
    'service-details' => 'Détails du service',
    'service-overview' => 'Aperçu du service sur "%s"',
    'title-pages-link' => 'Voir la page',
    'title-pdf-link' => 'Extraction PDF',
    'title-xml-link' => 'Extraction XML',
    'title-statistics-link' => 'Voir statistiques internes sur PNP',
    'title-calendar-link' => 'Définir une plage de temps',
    'title-special-templates-link' => 'Voir les patrons',
    'title-docs-link' => 'Accèder à la documentation',
    'title-home-link' => 'Accèder aux graphiques',
    'docs-home' => 'Accueil',
    'docs-box-header' => 'Menu',
    'docs-header' => 'Version de la documentation %s',
    'back' => 'back',
    'mobile-all-hosts' => 'All Hosts',
    'mobile-search-hosts' => 'Search Hosts',
    'mobile-pages' => 'View Pages',
    'mobile-special-templates' => 'View Special Templates',
    'mobile-statistics' => 'View internal statistics',
    'mobile-go-classic' => 'Classic UI',
    'mobile-submit' => 'Submit',
    'basket-empty' => 'Basket is empty',
    'basket-show' => 'Show basket',
    'basket-clear' => 'Clear basket',
    'basket-remove' => 'Remove %s',
    'basket-add-item' => 'Add this item to my basket',
    'basket-add-service' => 'Add this service to my basket',
);
